Enum RecordType
Source #[repr(u8)]
pub enum RecordType {
Metadata = 0,
Initialization = 1,
String = 2,
Thread = 3,
Event = 4,
Blob = 5,
UserspaceObject = 6,
KernelObject = 7,
Scheduler = 8,
Log = 9,
Profiler = 10,
LargeBlob = 15,
}
Enumerates all known record types.
The kLargeRecord uses a 32-bit size field.
Formats the value using the given formatter.
Read more
Writes a copy of
self to the prefix of
dst.
Read more
Writes a copy of
self to the suffix of
dst.
Read more
Attempts to read the given
source as a
Self.
Read more
Attempts to read a
Self from the prefix of the given
source.
Read more
Attempts to read a
Self from the suffix of the given
source.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.