KernelObjectRecordHeader

Struct KernelObjectRecordHeader 

pub struct KernelObjectRecordHeader(/* private fields */);
Header word for an FXT Kernel Object record (RecordType = 7).

Implementations

Source

impl KernelObjectRecordHeader

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const ARG_COUNT_MASK: u64

Unshifted bitmask of arg_count.

pub const ARG_COUNT_SHIFT: usize = 40

Bit shift (i.e., the low bit) of arg_count.

pub const NAME_REF_MASK: u64

Unshifted bitmask of name_ref.

pub const NAME_REF_SHIFT: usize = 24

Bit shift (i.e., the low bit) of name_ref.

pub const OBJ_TYPE_MASK: u64

Unshifted bitmask of obj_type.

pub const OBJ_TYPE_SHIFT: usize = 16

Bit shift (i.e., the low bit) of obj_type.

pub const RECORD_SIZE_MASK: u64

Unshifted bitmask of record_size.

pub const RECORD_SIZE_SHIFT: usize = 4

Bit shift (i.e., the low bit) of record_size.

pub const RECORD_TYPE_MASK: u64

Unshifted bitmask of record_type.

pub const RECORD_TYPE_SHIFT: usize = 0

Bit shift (i.e., the low bit) of record_type.

pub const RECORD_TYPE_DEFAULT: u64

Pre-shifted default value of the record_type field.

pub const FIELDS: [FieldMetadata<u64>; 5]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn arg_count(&self) -> u8

The value of KernelObjectRecordHeader[43:40].

pub const fn set_arg_count(&mut self, value: u8) -> &mut Self

Sets the value of KernelObjectRecordHeader[43:40].

pub const fn name_ref(&self) -> u16

The value of KernelObjectRecordHeader[39:24].

pub const fn set_name_ref(&mut self, value: u16) -> &mut Self

Sets the value of KernelObjectRecordHeader[39:24].

pub const fn obj_type(&self) -> u8

The value of KernelObjectRecordHeader[23:16].

pub const fn set_obj_type(&mut self, value: u8) -> &mut Self

Sets the value of KernelObjectRecordHeader[23:16].

pub const fn record_size(&self) -> u16

The value of KernelObjectRecordHeader[15:4].

pub const fn set_record_size(&mut self, value: u16) -> &mut Self

Sets the value of KernelObjectRecordHeader[15:4].

pub fn record_type(&self) -> RecordType

The value of KernelObjectRecordHeader[3:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_record_type to recover from invalid bit patterns.

pub fn try_record_type(&self) -> Result<RecordType, InvalidBits<u8>>

Fallible variant of Self::record_type.

pub fn set_record_type(&mut self, value: RecordType) -> &mut Self

Sets the value of KernelObjectRecordHeader[3:0].

Source

impl KernelObjectRecordHeader

pub fn iter(&self) -> KernelObjectRecordHeaderIter

Returns an iterator over (metadata, value) pairs for each field.