RecordHeader

Struct RecordHeader 

pub struct RecordHeader(/* private fields */);
Header word for a standard FXT record.

Implementations

Source

impl RecordHeader

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const RECORD_SIZE_MASK: u64

Unshifted bitmask of record_size.

pub const RECORD_SIZE_SHIFT: usize = 4

Bit shift (i.e., the low bit) of record_size.

pub const RECORD_TYPE_MASK: u64

Unshifted bitmask of record_type.

pub const RECORD_TYPE_SHIFT: usize = 0

Bit shift (i.e., the low bit) of record_type.

pub const FIELDS: [FieldMetadata<u64>; 2]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn record_size(&self) -> u16

The value of RecordHeader[15:4].

pub const fn set_record_size(&mut self, value: u16) -> &mut Self

Sets the value of RecordHeader[15:4].

pub fn record_type(&self) -> RecordType

The value of RecordHeader[3:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_record_type to recover from invalid bit patterns.

pub fn try_record_type(&self) -> Result<RecordType, InvalidBits<u8>>

Fallible variant of Self::record_type.

pub fn set_record_type(&mut self, value: RecordType) -> &mut Self

Sets the value of RecordHeader[3:0].

Source

impl RecordHeader

pub fn iter(&self) -> RecordHeaderIter

Returns an iterator over (metadata, value) pairs for each field.