StringRecordHeader

Struct StringRecordHeader 

pub struct StringRecordHeader(/* private fields */);
Header word for an FXT String record (RecordType = 2).

Implementations

Source

impl StringRecordHeader

pub const RSVD1_MASK: u64

Mask of all reserved-as-1 bits.

pub const RSVD0_MASK: u64

Mask of all reserved-as-0 bits.

pub const DEFAULT: u64

The default value of the layout, combining all field defaults and reserved-as values.

pub const STRING_LEN_MASK: u64

Unshifted bitmask of string_len.

pub const STRING_LEN_SHIFT: usize = 32

Bit shift (i.e., the low bit) of string_len.

pub const STRING_INDEX_MASK: u64

Unshifted bitmask of string_index.

pub const STRING_INDEX_SHIFT: usize = 16

Bit shift (i.e., the low bit) of string_index.

pub const RECORD_SIZE_MASK: u64

Unshifted bitmask of record_size.

pub const RECORD_SIZE_SHIFT: usize = 4

Bit shift (i.e., the low bit) of record_size.

pub const RECORD_TYPE_MASK: u64

Unshifted bitmask of record_type.

pub const RECORD_TYPE_SHIFT: usize = 0

Bit shift (i.e., the low bit) of record_type.

pub const RECORD_TYPE_DEFAULT: u64

Pre-shifted default value of the record_type field.

pub const FIELDS: [FieldMetadata<u64>; 4]

Metadata of all named fields in the layout.

pub const fn new() -> Self

Creates a new instance with reserved-as-1 bits set and all other bits zeroed (i.e., with a value of Self::RSVD1_MASK).

pub const fn bits(self) -> u64

pub const fn string_len(&self) -> u16

The value of StringRecordHeader[46:32].

pub const fn set_string_len(&mut self, value: u16) -> &mut Self

Sets the value of StringRecordHeader[46:32].

pub const fn string_index(&self) -> u16

The value of StringRecordHeader[30:16].

pub const fn set_string_index(&mut self, value: u16) -> &mut Self

Sets the value of StringRecordHeader[30:16].

pub const fn record_size(&self) -> u16

The value of StringRecordHeader[15:4].

pub const fn set_record_size(&mut self, value: u16) -> &mut Self

Sets the value of StringRecordHeader[15:4].

pub fn record_type(&self) -> RecordType

The value of StringRecordHeader[3:0].

Panics

Panics if the field’s bit pattern is not a valid value of the custom representation. Use Self::try_record_type to recover from invalid bit patterns.

pub fn try_record_type(&self) -> Result<RecordType, InvalidBits<u8>>

Fallible variant of Self::record_type.

pub fn set_record_type(&mut self, value: RecordType) -> &mut Self

Sets the value of StringRecordHeader[3:0].

Source

impl StringRecordHeader

pub fn iter(&self) -> StringRecordHeaderIter

Returns an iterator over (metadata, value) pairs for each field.